@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pause_id;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -35,6 +35,12 @@ Philippe Bruhat (BooK).
 
 =item *
 
+2012-08-27 - v1.004
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.016.
+
+=item *
+
 2012-07-23 - v1.003
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.011.
@@ -139,6 +145,7 @@ AAKD
 AAKHTER
 AALLAN
 AAMEND
+AANANDJHA
 AANKHEN
 AANOAA
 AANZLOVAR
@@ -182,6 +189,7 @@ ABREY
 ABREZINS
 ABROSNAN
 ABS
+ABUALIGA
 ABUI
 ABURKE
 ABURLISON
@@ -191,6 +199,7 @@ ABYPAUL
 ACAJOU
 ACALPINI
 ACAMARI
+ACANFORA
 ACARVALHO
 ACB
 ACCA
@@ -206,6 +215,7 @@ ACHIMRU
 ACHOUNG
 ACID
 ACIDDEATH
+ACIDLEMON
 ACK
 ACKI
 ACMCMEN
@@ -239,6 +249,7 @@ ADDW
 ADEO
 ADEOLA
 ADESC
+ADESINGH
 ADIE
 ADIPALMA
 ADIRAJ
@@ -284,6 +295,7 @@ AFFC
 AFIACRE
 AFIELDS
 AFINDLAY
+AFL
 AFLOTT
 AFN
 AFOLEY
@@ -344,6 +356,7 @@ AJGOUGH
 AJKALD
 AJOHNSON
 AJOLMA
+AJPAGE
 AJPEACOCK
 AJUNG
 AJWANS
@@ -358,6 +371,7 @@ AKIHITO
 AKIMOV
 AKIRA
 AKISSANE
+AKIYM
 AKOBA
 AKOLB
 AKR
@@ -467,6 +481,7 @@ AMICHAUER
 AMIMOTO
 AMIRF
 AMIRI
+AMIRITE
 AMITSIDES
 AML
 AMLING
@@ -608,6 +623,7 @@ ARACKHAEN
 ARAK
 ARANDAL
 ARAVIND
+ARAVINDDH
 ARAVINDR
 ARC
 ARCANEZ
@@ -734,6 +750,7 @@ ATG
 ATH
 ATHOMAS
 ATHOMASON
+ATIFK
 ATISTLER
 ATODOROV
 ATOM
@@ -780,6 +797,8 @@ AVOROBEY
 AVP
 AVUSEROW
 AWA
+AWBAUM
+AWC
 AWENDT
 AWESTHOLM
 AWGIBBS
@@ -809,8 +828,10 @@ AZJADFTRE
 AZOLIA
 AZS
 AZUL
+AZZID
 BABAR
 BABF
+BABKIN
 BACEK
 BACHMANN
 BADAJOZ
@@ -870,6 +891,7 @@ BASHI
 BASHINSKY
 BASHLOV
 BASKAR
+BASLOCK
 BASTIAN
 BAT
 BATKINS
@@ -1012,6 +1034,7 @@ BGIBBY
 BGILLS
 BGILMORE
 BGINGERY
+BGPMON
 BGRAY
 BGRIMM
 BGUARRACI
@@ -1087,6 +1110,7 @@ BJTURNER
 BJWHEELER
 BKA
 BKANEY
+BKATZUNG
 BKB
 BKCHAPIN
 BKENDI
@@ -1102,6 +1126,7 @@ BKW
 BLABES
 BLABOS
 BLACKAVAR
+BLACKHAWK
 BLACKJ
 BLACKSTAR
 BLADE
@@ -1135,6 +1160,7 @@ BLX
 BLYNCH
 BMAMES
 BMARCOTTE
+BMARTIN
 BMAVT
 BMAYNARD
 BMC
@@ -1459,6 +1485,7 @@ CASWK
 CAT
 CATALIN
 CATERHAM
+CATFU
 CATONE
 CAUGUSTIN
 CAUSTIN
@@ -1477,6 +1504,7 @@ CBERNING
 CBERRY
 CBHAMLIN
 CBHICKS
+CBINX
 CBIONDO
 CBOURNE
 CBOUVI
@@ -1669,6 +1697,7 @@ CKEITH
 CKERNER
 CKFULTON
 CKIMBER
+CKJ
 CKONG
 CKRAS
 CKRUSE
@@ -1707,6 +1736,7 @@ CLOTHO
 CLOWN
 CLP
 CLSCOTT
+CLSN
 CLSUNG
 CLUNIS
 CLWOLFE
@@ -1743,6 +1773,9 @@ CNIGHS
 CNLAVY
 CNRDEEIO
 CNX
+CODEAH
+CODEBLACK
+CODEBREAK
 CODECHILD
 CODEFISH
 CODEHELP
@@ -1935,6 +1968,7 @@ CZBSD
 DAAN
 DACONTI
 DADAMK
+DADERUS
 DADIS
 DAEMON
 DAGOBERT
@@ -2018,6 +2052,7 @@ DASHJR
 DATA
 DATABUILT
 DATCHLEY
+DATOPDOG
 DAUNAY
 DAV
 DAVAZ
@@ -2127,6 +2162,7 @@ DCT
 DDAY
 DDB
 DDEBRITO
+DDEIMEKE
 DDF
 DDICK
 DDOKTER
@@ -2150,6 +2186,7 @@ DECASM
 DECAY
 DECIUS
 DEDMEDVED
+DEDRICK
 DEEMON
 DEENEWCUM
 DEEPAK
@@ -2252,6 +2289,7 @@ DGREGORY
 DGRIS
 DGRIZZANT
 DGROVER
+DGRYSKI
 DGSCOPE
 DGUY
 DHA
@@ -2318,6 +2356,7 @@ DJBURKE
 DJCE
 DJCONNEL
 DJCP
+DJCURTIS
 DJERIUS
 DJGOKU
 DJH
@@ -2415,6 +2454,7 @@ DODYSW
 DOGAN
 DOGGY
 DOHERTY
+DOKADON
 DOKSNER
 DOLIVEIRA
 DOLMEN
@@ -2666,6 +2706,7 @@ ECLARK
 ECOCODE
 ECTO
 EDALY
+EDAM
 EDAVIS
 EDB
 EDD
@@ -2920,6 +2961,7 @@ FANTONSEN
 FANY
 FAPG
 FARBER
+FARHAD
 FARHADM
 FARIS
 FARO
@@ -2991,6 +3033,7 @@ FKALTER
 FKIORI
 FKOENEN
 FKOLODNY
+FKREIJM
 FKUO
 FLAME
 FLAMEY
@@ -3031,6 +3074,7 @@ FOOCHRE
 FOOF
 FOOLFISH
 FOOLISH
+FOOP
 FORMAN
 FORMORER
 FORREST
@@ -3404,10 +3448,12 @@ GRODITI
 GROMMEL
 GROMMIER
 GROOVIS
+GROSOURS
 GROSSMANN
 GROUSSE
 GROVED
 GRUBER
+GRUBERT
 GRUDZIAR
 GRUNDEI
 GRYDUNCAN
@@ -3592,6 +3638,7 @@ HENRIK
 HENRIKS
 HENROID
 HENRYYKT
+HENTEKO
 HERBERTS
 HERNAN
 HERRERA
@@ -3641,6 +3688,7 @@ HIROYUKIM
 HISAJU
 HISELDL
 HISSO
+HITAPEX
 HITHERTO
 HITSU
 HJANSEN
@@ -3927,6 +3975,7 @@ ITEAHAUS
 ITEGEBO
 ITGURU
 ITMFROLOV
+ITNOMAD
 ITRIVIZKI
 ITRUNAEV
 ITSME
@@ -4166,6 +4215,7 @@ JDOUGLAS
 JDPORTER
 JDR
 JDRAGO
+JDS
 JDUARTER
 JDUNCAN
 JDUTTON
@@ -4197,6 +4247,7 @@ JEFPONOT
 JEGADE
 JEGAN
 JELLMAN
+JELU
 JENDA
 JENKINSON
 JENKSTER
@@ -4257,6 +4308,7 @@ JFREEMAN
 JFRIED
 JFRIEDL
 JFROEBE
+JFROSTH
 JFS
 JFURNESS
 JGAMBLE
@@ -4337,6 +4389,7 @@ JIMW
 JINGRAM
 JINKEE
 JIRA
+JIRAPL
 JIRO
 JIRWIN
 JJACK
@@ -4839,7 +4892,9 @@ KAWASAKI
 KAYSB
 KAZEBURO
 KAZIMIROV
+KAZUHISA
 KAZUHO
+KAZUNORI
 KBA
 KBALBI
 KBARBER
@@ -4955,6 +5010,7 @@ KHUSSEIN
 KHW
 KIANWIN
 KID
+KIELSTR
 KILINRAX
 KILNA
 KILORK
@@ -5025,6 +5081,7 @@ KMCGRATH
 KMEHTA
 KMELTZ
 KMIYAZAKI
+KMOHARANA
 KMR
 KMX
 KNAGANO
@@ -5033,6 +5090,7 @@ KNASSAR
 KNEW
 KNI
 KNIGHT
+KNJSKYWKR
 KNM
 KNOEFEL
 KNOK
@@ -5671,6 +5729,7 @@ MARKJ
 MARKJJNSN
 MARKK
 MARKLE
+MARKLEEUW
 MARKM
 MARKNG
 MARKO
@@ -5687,6 +5746,7 @@ MARKWIN
 MARKWKM
 MARMS
 MARNANEL
+MARNIX
 MAROS
 MARR
 MARROTTE
@@ -5884,6 +5944,7 @@ MDOM
 MDOOTSON
 MDORMAN
 MDOWNING
+MDPERRY
 MDUNHAM
 MDUPONT
 MDVALLEY
@@ -6003,6 +6064,7 @@ MICHIELB
 MICKWEISS
 MICLAR
 MICOAMS
+MICROFT
 MICU
 MICVU
 MIDDLETO
@@ -6074,6 +6136,7 @@ MIRABELLA
 MIRE
 MIRELL
 MIRK
+MIRKO
 MIROD
 MIRROROK
 MIRRORS
@@ -6085,6 +6148,7 @@ MISHIKAL
 MISHIN
 MISHOO
 MIST
+MISTI
 MIT
 MITEL
 MITHALDU
@@ -6159,6 +6223,7 @@ MLING
 MLONGTIN
 MLRU
 MLS
+MLUCERO
 MLUKER
 MLX
 MMABRY
@@ -6275,6 +6340,7 @@ MPCZ
 MPECK
 MPELZER
 MPEREZ
+MPERRY
 MPETERS
 MPG
 MPGUTTA
@@ -6602,6 +6668,7 @@ NGLEDHILL
 NGLENN
 NGRUNWALD
 NGS
+NHAINER
 NHARALE
 NHEINRIC
 NHORNE
@@ -6615,6 +6682,7 @@ NICKH
 NICKOLA
 NICKS
 NICO
+NICOLAE
 NICOLAW
 NICOMEN
 NICS
@@ -6648,6 +6716,7 @@ NINJA
 NINJAZ
 NINUZZO
 NIRAVE
+NIRIX
 NIRMA
 NI_S
 NISHANT
@@ -6741,6 +6810,7 @@ NUANCE
 NUBA
 NUCLON
 NUCWIN
+NUDDLEGG
 NUF
 NUFFIN
 NURAB
@@ -6771,6 +6841,7 @@ OBOGREW
 OBRADOVIC
 OBULON
 OCEANLAB
+OCHEUNG
 OCROW
 OCTO
 ODDFELLOW
@@ -6880,6 +6951,7 @@ OUBIWANN
 OUEST
 OVAL
 OVENMAN
+OVERLAST
 OVERMARS
 OVID
 OWEN
@@ -6903,6 +6975,7 @@ PAKALRA
 PALANT
 PALIK
 PALLOTRON
+PALPATE
 PALVARO
 PAMAG
 PANDICH
@@ -6920,6 +6993,7 @@ PARASEW
 PARCHER
 PARDUS
 PARI
+PARIZHE
 PARKER
 PARROTRE
 PARTICLE
@@ -6936,6 +7010,7 @@ PATBAKER
 PATBHATK
 PATCH
 PATL
+PATLAN
 PATM
 PATRICK
 PATTERNER
@@ -6949,6 +7024,7 @@ PAULJUDGE
 PAULLAM
 PAULM
 PAULO
+PAULOKING
 PAULPG
 PAULV
 PAULW
@@ -6983,6 +7059,7 @@ PCMANTZ
 PCOLLINS
 PCSJJ
 PCZERKAS
+PDBKANGE
 PDCAWLEY
 PDEEGAN
 PDENIS
@@ -7206,6 +7283,7 @@ PLEGALL
 PLEO
 PLEXUS
 PLIAM
+PLICEASE
 PLISCO
 PLISTER
 PLOBBES
@@ -7541,10 +7619,12 @@ RDO
 RDP
 RDRAKE
 RDROUSIES
+RDSMITHAZ
 RDUARTE
 REALHOLGI
 REATMON
 REBEL
+REBOS
 REBX
 RECKON
 RECLAW
@@ -7584,6 +7664,7 @@ REUSSERL
 REUVEN
 REV
 REVMISCHA
+REVOLET
 REVPREZ
 REVSBECH
 REYNOLDS
@@ -7710,6 +7791,7 @@ RKJISM
 RKOBES
 RKOCHERL
 RKOWEN
+RKRIEGER
 RKRIMEN
 RKS
 RLANDRUM
@@ -8014,6 +8096,7 @@ SAPER
 SAPERSKI
 SAR
 SARAVANAN
+SARAVASE
 SARENNER
 SARFY
 SARGE
@@ -8077,6 +8160,7 @@ SCHOEN
 SCHOP
 SCHRIECK
 SCHROEER
+SCHRORG
 SCHUBIGER
 SCHUBOE
 SCHUETT
@@ -8131,6 +8215,7 @@ SDP
 SDPRICE
 SDRABBLE
 SDT
+SDUBS
 SEAGIRL
 SEAHEN
 SEANBO
@@ -8279,6 +8364,7 @@ SHMEM
 SHMORIMO
 SHOEPHONE
 SHOGE
+SHOHEIK
 SHOK
 SHOLDEN
 SHOMODJ
@@ -8407,6 +8493,7 @@ SKUNZ
 SKUPSY
 SKUZN
 SKX
+SKYEND
 SKYFIVE
 SKYHAWK
 SLAFF
@@ -8515,6 +8602,7 @@ SOMU
 SOMUP
 SONAM
 SONDBERG
+SONDIEK
 SONGMU
 SONNEN
 SONNY
@@ -8631,6 +8719,7 @@ SSNODGRA
 SSORICHE
 SSOTKA
 SSOURABH
+SSQQ
 SSWAM
 STABILE
 STAJICH
@@ -8649,6 +8738,7 @@ STCHER
 STE
 STEALTHY
 STEF
+STEFAANC
 STEFAN
 STEFANOS
 STEFANRAM
@@ -8796,6 +8886,7 @@ SWEN
 SWESTRUP
 SWETH
 SWFLINT
+SWHIRSCH
 SWHITAKER
 SWILCOX
 SWILLIAM
@@ -8878,6 +8969,7 @@ TAREKA
 TARO
 TAROK
 TARSKI
+TARXVF
 TARYK
 TASMIN
 TATE
@@ -9055,6 +9147,7 @@ TJMC
 TJOHNSON
 TJORGEN
 TJORMOLA
+TJRANDALL
 TJUGO
 TJWALKER
 TJYANG
@@ -9187,6 +9280,7 @@ TQISJIM
 TRACKONE
 TRANSWEBT
 TRAVAIL
+TRAVIS
 TRBC
 TRCJR
 TREEKI
@@ -9214,6 +9308,7 @@ TROYP
 TRSKI
 TRUELSEN
 TRUESDALE
+TRUEY
 TRUSTCOM
 TRWWW
 TRYM
@@ -9651,6 +9746,7 @@ WNGDN
 WNODOM
 WOADEV
 WOHL
+WOHLFARJ
 WOLDRICH
 WOLF
 WOLFEN
@@ -9682,6 +9778,7 @@ WREN
 WRILEY
 WROG
 WROSS
+WRUPPERT
 WRW
 WSANNIS
 WSCHL
@@ -9847,6 +9944,7 @@ YOSHIMI
 YOSHIOKA
 YOSTY
 YOU
+YOUAM
 YOUD
 YOUNG
 YOURABI
